#!/bin/bash
#
# author           : Hugo Santos (bitker~AT~gmail.com)
# latest update    : 04-05-2007
# source location  : http://wizard.ae.krakow.pl/~mike/
# url              : http://wizard.ae.krakow.pl/~mike/download/whowatch-1.4.tar.gz

NAME=whowatch
VERSION=1.4
ARCH=${ARCH:-i486}
CPU=${CPU:-i686}
BUILD=${BUILD:-46.1}
TMP=${TMP:-/tmp}
PKG=$TMP/package-$NAME
CWD=`pwd`
EXTENSION=tar.gz

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
#numjobs='-j2'

rm -rf $PKG
mkdir -p $PKG

cd $TMP
rm -rf $NAME-$VERSION
  if [ -f $NAME-$VERSION.$EXTENSION ]; then
          echo "Source file already here, no need to re-download";
  elif [ -f $CWD/$NAME-$VERSION.$EXTENSION ]; then
          echo -n "Relocating source file to $TMP..."
          cp $CWD/$NAME-$VERSION.$EXTENSION $TMP/
	  echo "done"
  else
	  wget -c http://wizard.ae.krakow.pl/~mike/download/$NAME-$VERSION.$EXTENSION
  fi
  tar xf $NAME-$VERSION.$EXTENSION

cd $NAME-$VERSION


#Pacth for gcc4
  if [ -f gcc4-fix.patch ]; then
          echo "Source file already here, no need to re-download";
  else
	  wget -c http://svn.rpmforge.net/svn/trunk/rpms/whowatch/gcc4-fix.patch
  fi
  patch -p1 < gcc4-fix.patch

# Configure:
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure \
  --prefix=/usr

# Build and install:
sed -i -e 's|$(INSTALL) -m 755 whowatch $(bindir)/whowatch|$(INSTALL) -m 755 whowatch $(DESTDIR)$(bindir)/whowatch|g' Makefile
sed -i -e 's|$(INSTALL) -m 644 whowatch.1 $(mandir)/man1/whowatch.1|$(INSTALL) -m 644 whowatch.1 $(DESTDIR)$(mandir)/man1/whowatch.1|g' Makefile
mkdir -p $PKG/usr/bin
mkdir -p $PKG/usr/man/man1
make $numjobs || exit 1
make install DESTDIR=$PKG || exit 1

# Strip binaries:
( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress the man page(s)
if [ -d $PKG/usr/man ]; then
	find $PKG/usr/man -type f -name "*.?" -exec gzip -9f {} \;
fi
if [ -d $PKG/usr/info ]; then
	find $PKG/usr/info -type f -name "*.info*" -exec gzip -9f {} \;
fi

# Add a documentation directory:
mkdir -p $PKG/usr/doc/$NAME-$VERSION

# The Makefile evidently contains the package's license...
DOCS="AUTHORS ChangeLog INSTALL NEWS COPYING KEYS README TODO"
cd $TMP/$NAME-$VERSION
cp -a \
  $DOCS \
  $PKG/usr/doc/$NAME-$VERSION

# 
# as per package rules: add the build-file itself
#
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp gcc4-fix.patch "$PKG/usr/src/$NAME-$VERSION/"
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

mkdir -p $PKG/install

echo "$NAME: $NAME 
$NAME: Whowatch is an interactive console utility that displays informations about
$NAME: the users currently logged on to the machine, in real time. Besides standard
$NAME: information (login, tty, host, user's process) you can see type of login
$NAME: (ie. ssh, telnet). You can also see selected user's processes tree or all
$NAME: system processes tree.  In the process tree mode there is ability to send
$NAME: INT or KILL signal to selected process.
$NAME:
$NAME:
$NAME:
$NAME: Compiled for Zenwalk" > $PKG/install/slack-desc

#
# real packaging work:
#
# Make sure ownerships and permissions are sane:
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n ../$NAME-$VERSION-$ARCH-$BUILD.tgz

#
# computes the md5sum signature and finding dependencies for the package
#
cd $TMP
echo "Compute MD5..."
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5
echo "Finding dependencies..."
requiredbuilder -z $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.dep
